RefNode

Enum RefNode 

pub enum RefNode {
    StartAgent {
        span: (usize, usize),
    },
    Topic {
        name: String,
        span: (usize, usize),
    },
    ActionDef {
        name: String,
        topic: String,
        span: (usize, usize),
    },
    ReasoningAction {
        name: String,
        topic: String,
        target: Option<String>,
        span: (usize, usize),
    },
    Variable {
        name: String,
        mutable: bool,
        span: (usize, usize),
    },
    Connection {
        name: String,
        span: (usize, usize),
    },
}
A node in the reference graph representing a definition.

Variants



StartAgent

The start_agent entry point

Fields

span: (usize, usize)

Source location



Topic

A topic definition

Fields

name: String

Topic name

span: (usize, usize)

Source location



ActionDef

An action definition within a topic

Fields

name: String

Action name

topic: String

Parent topic name

span: (usize, usize)

Source location



ReasoningAction

A reasoning action within a topic

Fields

name: String

Reasoning action name

topic: String

Parent topic name

target: Option<String>

The target action or topic this reasoning action invokes

span: (usize, usize)

Source location



Variable

A variable definition

Fields

name: String

Variable name

mutable: bool

Whether this is a mutable variable

span: (usize, usize)

Source location



Connection

A connection/escalation definition

Fields

name: String

Connection name

span: (usize, usize)

Source location

Implementations

Source

impl RefNode

pub fn label(&self) -> String

Get a human-readable label for this node.

pub fn span(&self) -> (usize, usize)

Get the source span for this node.

pub fn name(&self) -> Option<&str>

Get the name of this node (if applicable).

pub fn is_topic(&self) -> bool

Check if this node is a topic.

pub fn is_action_def(&self) -> bool

Check if this node is an action definition.

pub fn is_reasoning_action(&self) -> bool

Check if this node is a reasoning action.

pub fn is_variable(&self) -> bool

Check if this node is a variable.