pub enum Token<'src> {
Show 112 variants
Config,
Variables,
System,
StartAgent,
Topic,
Actions,
Inputs,
Outputs,
Target,
Reasoning,
Instructions,
BeforeReasoning,
AfterReasoning,
Messages,
Welcome,
Error,
Connection,
Connections,
Knowledge,
Language,
Mutable,
Linked,
Description,
Source,
Label,
IsRequired,
IsDisplayable,
IsUsedByPlanner,
ComplexDataTypeName,
FilterFromAgent,
RequireUserConfirmation,
IncludeInProgressIndicator,
ProgressIndicatorMessage,
String,
Number,
Boolean,
Object,
List,
Date,
Timestamp,
Currency,
Id,
Datetime,
Time,
Integer,
Long,
If,
Else,
Run,
With,
Set,
To,
As,
Transition,
Available,
When,
True,
False,
None,
Eq,
Ne,
Lt,
Gt,
Le,
Ge,
Assign,
Is,
Not,
And,
Or,
Plus,
Minus,
Colon,
Dot,
Comma,
At,
Pipe,
Arrow,
ColonPipe,
ColonArrow,
LParen,
RParen,
LBracket,
RBracket,
LBrace,
RBrace,
ExclBrace,
DoubleLBrace,
DoubleBrace,
Ellipsis,
Slash,
Question,
Exclamation,
Dollar,
Percent,
Star,
Ampersand,
Semicolon,
Backtick,
Tilde,
Caret,
Backslash,
Underscore,
Apostrophe,
UnicodeText(&'src str),
Ident(&'src str),
StringLit(&'src str),
NumberLit(f64),
Comment(&'src str),
Newline,
Indent,
Dedent,
}Expand description
A token in AgentScript.
Tokens are the atomic units produced by the lexer. Each token represents a meaningful element of the source code.
Variants
Config
Variables
System
StartAgent
Topic
Actions
Inputs
Outputs
Target
Reasoning
Instructions
BeforeReasoning
AfterReasoning
Messages
Welcome
Error
Connection
Connections
Knowledge
Language
Mutable
Linked
Description
Label
IsRequired
IsDisplayable
IsUsedByPlanner
ComplexDataTypeName
FilterFromAgent
RequireUserConfirmation
IncludeInProgressIndicator
ProgressIndicatorMessage
String
Number
Boolean
Object
List
Date
Timestamp
Currency
Id
Datetime
Time
Integer
Long
If
Else
Run
With
Set
To
As
Transition
Available
When
True
False
None
Eq
Ne
Lt
Gt
Le
Ge
Assign
Is
Not
And
Or
Plus
Minus
Colon
Dot
Comma
At
Pipe
Arrow
ColonPipe
ColonArrow
LParen
RParen
LBracket
RBracket
LBrace
RBrace
ExclBrace
DoubleLBrace
DoubleBrace
Ellipsis
Slash
Question
Exclamation
Dollar
Percent
Star
Ampersand
Semicolon
Backtick
Tilde
Caret
Backslash
Underscore
Apostrophe
UnicodeText(&'src str)
Ident(&'src str)
StringLit(&'src str)
NumberLit(f64)
Comment(&'src str)
Newline
Indent
Dedent