pub fn parse_with_structured_errors(
source: &str,
) -> Result<AgentFile, Vec<ParseErrorInfo>>Expand description
Parse an AgentScript file and return structured errors with span information.
Returns Ok only if parsing succeeds with no errors.
Use parse_with_structured_errors_all to get partial results and all errors.